@@ -78,6 +78,9 @@ BEGIN_EVENT_TABLE(ImagesTreeCtrl, wxTreeListCtrl)
     EVT_TREE_KEY_DOWN(-1, ImagesTreeCtrl::OnChar)
     EVT_TREE_BEGIN_LABEL_EDIT(-1, ImagesTreeCtrl::OnBeginEdit)
     EVT_TREE_END_LABEL_EDIT(-1, ImagesTreeCtrl::OnEndEdit)
+#if wxCHECK_VERSION(3,1,3)
+    EVT_DPI_CHANGED(ImagesTreeCtrl::OnDpiChanged)
+#endif
 END_EVENT_TABLE()
 
 class ImagesTreeData : public wxTreeItemData
@@ -566,12 +569,25 @@ void ImagesTreeCtrl::UpdateImageText(wxTreeItemId item)
     }
     else
     {
-        std::vector<float> vec=img.getEMoRParams();
-        SetItemText(item, m_columnMap["Ra"], hugin_utils::doubleTowxString(vec[0],m_distDigits));
-        SetItemText(item, m_columnMap["Rb"], hugin_utils::doubleTowxString(vec[1],m_distDigits));
-        SetItemText(item, m_columnMap["Rc"], hugin_utils::doubleTowxString(vec[2],m_distDigits));
-        SetItemText(item, m_columnMap["Rd"], hugin_utils::doubleTowxString(vec[3],m_distDigits));
-        SetItemText(item, m_columnMap["Re"], hugin_utils::doubleTowxString(vec[4],m_distDigits));
+        if (img.getResponseType() == HuginBase::SrcPanoImage::RESPONSE_EMOR)
+        {
+            // display Ra..Re only when response type is emor
+                        // otherwise they have no meaning
+            std::vector<float> vec = img.getEMoRParams();
+            SetItemText(item, m_columnMap["Ra"], hugin_utils::doubleTowxString(vec[0], m_distDigits));
+            SetItemText(item, m_columnMap["Rb"], hugin_utils::doubleTowxString(vec[1], m_distDigits));
+            SetItemText(item, m_columnMap["Rc"], hugin_utils::doubleTowxString(vec[2], m_distDigits));
+            SetItemText(item, m_columnMap["Rd"], hugin_utils::doubleTowxString(vec[3], m_distDigits));
+            SetItemText(item, m_columnMap["Re"], hugin_utils::doubleTowxString(vec[4], m_distDigits));
+        }
+        else
+        {
+            SetItemText(item, m_columnMap["Ra"], wxEmptyString);
+            SetItemText(item, m_columnMap["Rb"], wxEmptyString);
+            SetItemText(item, m_columnMap["Rc"], wxEmptyString);
+            SetItemText(item, m_columnMap["Rd"], wxEmptyString);
+            SetItemText(item, m_columnMap["Re"], wxEmptyString);
+        };
     };
 };
 
@@ -750,7 +766,7 @@ void ImagesTreeCtrl::UpdateGroupText(wxTreeItemId item)
             SetItemText(item, m_columnMap["Vy"], wxEmptyString);
         };
 
-        if (m_groupMode == GROUP_LENS && (img.EMoRParamsisLinked() || haveSingleChild))
+        if (m_groupMode == GROUP_LENS && (img.getResponseType() == HuginBase::SrcPanoImage::RESPONSE_EMOR && (img.EMoRParamsisLinked()) || haveSingleChild))
         {
             std::vector<float> vec=img.getEMoRParams();
             SetItemText(item, m_columnMap["Ra"], hugin_utils::doubleTowxString(vec[0],m_distDigits));
@@ -942,12 +958,8 @@ void ImagesTreeCtrl::SetGuiLevel(GuiLevel newSetting)
     SetDisplayMode(m_displayMode);
 };
 
-void ImagesTreeCtrl::SetOptimizerMode()
+void ImagesTreeCtrl::CreateCheckboxImages()
 {
-    m_optimizerMode=true;
-    // connnect events with handlers
-    Bind(wxEVT_MOTION, &ImagesTreeCtrl::OnMouseMove, this);
-    Bind(wxEVT_LEFT_DOWN, &ImagesTreeCtrl::OnLeftDown, this);
     //create bitmaps for different checkboxes state
     wxRendererNative& renderer = wxRendererNative::Get();
     const wxSize checkBoxSize = renderer.GetCheckBoxSize(this);
@@ -979,6 +991,16 @@ void ImagesTreeCtrl::SetOptimizerMode()
     checkboxImageList->Add(checkBoxImage);
 
     AssignImageList(checkboxImageList);
+}
+
+void ImagesTreeCtrl::SetOptimizerMode()
+{
+    m_optimizerMode=true;
+    // connnect events with handlers
+    Bind(wxEVT_MOTION, &ImagesTreeCtrl::OnMouseMove, this);
+    Bind(wxEVT_LEFT_DOWN, &ImagesTreeCtrl::OnLeftDown, this);
+    // build image list with check box images
+    CreateCheckboxImages();
     // activate edit mode
     for(HuginBase::UIntSet::const_iterator it=m_editableColumns.begin(); it!=m_editableColumns.end(); ++it)
     {
@@ -987,7 +1009,19 @@ void ImagesTreeCtrl::SetOptimizerMode()
             SetColumnEditable(*it,true);
         };
     };
-};
+}
+
+#if wxCHECK_VERSION(3,1,3)
+void ImagesTreeCtrl::OnDpiChanged(wxDPIChangedEvent& e)
+{
+    // dpi has changed, we need to update the images of the checkboxes
+    if (m_optimizerMode)
+    {
+        CreateCheckboxImages();
+        Refresh();
+    };
+}
+#endif
 
 void ImagesTreeCtrl::SetGroupMode(GroupMode newGroup)
 {
