@@ -36,8 +36,7 @@
 // workaround for a conflict between exiv2 and wxWidgets/CMake built
 #define HAVE_PID_T 1
 #endif
-#include <exiv2/exif.hpp>
-#include <exiv2/image.hpp>
+#include <exiv2/exiv2.hpp>
 #include "base_wx/LensTools.h"
 #include "base_wx/wxLensDB.h"
 #include "hugin/ResetDialog.h"
@@ -234,7 +233,7 @@ PanoCommand::PanoCommand* AddImageOperation::GetInternalCommand(wxWindow* parent
                         wxT(""),
 #endif
                         wxICON_EXCLAMATION | wxYES_NO );
-                    message.SetYesNoLabels(_("Convert anyway."), _("Let me select several raw files."));
+                    message.SetYesNoLabels(_("Convert anyway"), _("Let me select several raw files"));
                     if (message.ShowModal() == wxID_NO)
                     {
                         // post new add image event to open dialog again
@@ -268,7 +267,11 @@ WX_DECLARE_STRING_HASH_MAP(int, StringToFlagHash);
 
 time_t ReadExifTime(const char* filename)
 {
+#if defined EXIV2_VERSION && EXIV2_TEST_VERSION(0,27,99)
+    Exiv2::Image::UniquePtr image;
+#else
     Exiv2::Image::AutoPtr image;
+#endif
     try
     {
         image = Exiv2::ImageFactory::open(filename);
@@ -282,7 +285,15 @@ time_t ReadExifTime(const char* filename)
         return 0;
     }
 
-    image->readMetadata();
+    try
+    {
+        image->readMetadata();
+    }
+    catch (const Exiv2::Error& e)
+    {
+        std::cerr << "Exiv2: Error reading metadata (" << e.what() << ")" << std::endl;
+        return 0;
+    }
     Exiv2::ExifData &exifData = image->exifData();
     if (exifData.empty())
     {
@@ -521,11 +532,6 @@ PanoCommand::PanoCommand* ChangeColorAnchorImageOperation::GetInternalCommand(wx
 {
     HuginBase::PanoramaOptions opt = pano.getOptions();
     opt.colorReferenceImage = *(images.begin());
-    // Set the color correction mode so that the anchor image is persisted
-    if (opt.colorCorrection == 0)
-    {
-        opt.colorCorrection = (HuginBase::PanoramaOptions::ColorCorrection) 1;
-    }
     return new PanoCommand::SetPanoOptionsCmd(pano, opt);
 };
 
@@ -583,6 +589,23 @@ PanoCommand::PanoCommand* ChangeLensOperation::GetInternalCommand(wxWindow* pare
     if (nr >= 0)
     {
         // user accepted
+        // check that image size are the same
+        const vigra::Size2D lensImgSize = variable_groups.getLens(nr).getImageSize();
+        for (const auto& img : images)
+        {
+            if (pano.getImage(img).getSize() != lensImgSize)
+            {
+                wxMessageBox(wxString::Format(_("Selected images and selected lens have different sizes. All images of the same lens should have the same size.\n\nImage %d has size %dx%d, while lens %d has images with size of %dx%d pixel."),
+                    img, pano.getImage(img).getWidth(), pano.getImage(img).getHeight(), nr, lensImgSize.width(), lensImgSize.height()),
+#ifdef __WXMSW__
+                    wxT("Hugin"),
+#else
+                    wxT(""),
+#endif
+                    wxICON_EXCLAMATION | wxOK);
+                return NULL;
+            };
+        };
         return new PanoCommand::ChangePartNumberCmd(pano, images, nr, HuginBase::StandardImageVariableGroups::getLensVariables());
     }
     else
@@ -1233,13 +1256,31 @@ PanoCommand::PanoCommand* ChangeStackOperation::GetInternalCommand(wxWindow* par
     HuginBase::StandardImageVariableGroups variable_groups(pano);
     long nr = wxGetNumberFromUser(
                             _("Enter new stack number"),
-                            _("stack number"),
+                            _("Stack number"),
                             _("Change stack number"), 0, 0,
                             variable_groups.getStacks().getNumberOfParts()-1
                                  );
     if (nr >= 0)
     {
         // user accepted
+        // check that image size are the same
+        const vigra::Size2D stackImgSize = pano.getImage(*variable_groups.getStacks().getPartsSet()[nr].begin()).getSize();
+        for (const auto& img : images)
+        {
+            if (pano.getImage(img).getSize() != stackImgSize)
+            {
+                wxMessageBox(wxString::Format(_("Selected images and selected stack have different sizes. All images of the same stack should have the same size.\n\nImage %d has size %dx%d, while stack %d has images with size of %dx%d pixel."),
+                    img, pano.getImage(img).getWidth(), pano.getImage(img).getHeight(), nr, stackImgSize.width(), stackImgSize.height()),
+#ifdef __WXMSW__
+                    wxT("Hugin"),
+#else
+                    wxT(""),
+#endif
+                    wxICON_EXCLAMATION | wxOK);
+                return NULL;
+            };
+        };
+
         return new PanoCommand::ChangePartNumberCmd(pano, images, nr, HuginBase::StandardImageVariableGroups::getStackVariables());
     }
     else
